==> splines2_0.2.4.tar.gz: splines2/NEWS.md <==
# CHANGES IN splines2 VERSION 0.2.4

## NEW FEATURES

* Added function `dbs` generating derivative of given order of B-splines. It is
  a similar function with `splines::splineDesign`. However, it provides a more
  user-friendly interface and more consistent handling on `NA`'s.

* Added `deriv` methods for derivatives of given order of any existing
  **splines2** object that can be generated currently.

## MAJOR CHANGES

* Added argument `derivs` to function `mSpline` and `iSpline` for derivatives.

* Changed all the classes of object generated for a better dispatching on
  methods.

## MINOR CHANGES

* Added tests for all major functions with the help of package **testthat**.

## BUG FIXES

* Fixed the generation of splines basis without any internal knot.


# CHANGES IN splines2 VERSION 0.2.3

## BUG FIXES

* Fixed one-piece constant basis for M-splines.


# CHANGES IN splines2 VERSION 0.2.2

## BUG FIXES

* Fixed the NA's handling in all the functions constructing spline bases.


# CHANGES IN splines2 VERSION 0.2.1

## NEW FEATURES

* Added function `bSpline` generating B-spline basis allowing zero degree or
  piecewise constant basis based on function `bs` in package **splines**.

* Introduced function `bSpline` to allow M-splines of degree zero.

* Added function `cSpline` constructing convex spline (C-spline) basis.

* Added `predict` methods for `bSpline2` object and `cSpline` object generated
  by `bSpline` and `cSpline`, respectively.

* Added `print` methods for all **splines2** objects developed so far.

## MAJOR CHANGES

* Improved the function `iSpline` to construct I-spline basis directly from
  B-spline basis instead of M-spline basis.

## MINOR CHANGES

* Updated all CRAN URL to a canonical form suggested.


# CHANGES IN splines2 VERSION 0.1.0

## NEW FEATURES

* The first version of **splines2** providing functions constructing M-spline,
  I-spline, and integral of B-spline basis.

==> splines2_0.2.5.tar.gz: splines2/NEWS.md <==
# CHANGES IN splines2 VERSION 0.2.5

## MINOR CHANGES

* Added more tests and increased code coverage.

## BUG FIXES

* Fixed evaluation of derivatives of M-splines for a single value. Thanks Ina
  Jazic for reporting the bug and providing possible fix.

* Fixed `deriv.cSpline` method for derivatives of order greater than two when
  `scale = TRUE`.


# CHANGES IN splines2 VERSION 0.2.4

## NEW FEATURES

* Added function `dbs` generating derivative of given order of B-splines. It is
  a similar function with `splines::splineDesign`. However, it provides a more
  user-friendly interface and more consistent handling on `NA`'s.

* Added `deriv` methods for derivatives of given order of any existing
  **splines2** object that can be generated currently.

## MAJOR CHANGES

* Added argument `derivs` to function `mSpline` and `iSpline` for derivatives.

* Changed all the classes of object generated for a better dispatching on
  methods.

## MINOR CHANGES

* Added tests for all major functions with the help of package **testthat**.

## BUG FIXES

* Fixed the generation of splines without any internal knot.


# CHANGES IN splines2 VERSION 0.2.3

## BUG FIXES

* Fixed one-piece constant basis for M-splines.


# CHANGES IN splines2 VERSION 0.2.2

## BUG FIXES

* Fixed the NA's handling in all the functions constructing spline bases.


# CHANGES IN splines2 VERSION 0.2.1

## NEW FEATURES

* Added function `bSpline` generating B-spline basis allowing zero degree or
  piecewise constant basis based on function `bs` in package **splines**.

* Introduced function `bSpline` to allow M-splines of degree zero.

* Added function `cSpline` constructing convex spline (C-spline) basis.

* Added `predict` methods for `bSpline2` object and `cSpline` object generated
  by `bSpline` and `cSpline`, respectively.

* Added `print` methods for all **splines2** objects developed so far.

## MAJOR CHANGES

* Improved the function `iSpline` to construct I-spline basis directly from
  B-spline basis instead of M-spline basis.

## MINOR CHANGES

* Updated all CRAN URL to a canonical form suggested.


# CHANGES IN splines2 VERSION 0.1.0

## NEW FEATURES

* The first version of **splines2** providing functions constructing M-spline,
  I-spline, and integral of B-spline basis.
